diff --git a/src/variable.cpp b/src/variable.cpp
index b0299d5..5250022 100644
--- a/src/variable.cpp
+++ b/src/variable.cpp
@@ -48,7 +48,7 @@ enum{ARG,OP};
 
 // customize by adding a function
 
-enum{DONE,ADD,SUBTRACT,MULTIPLY,DIVIDE,CARAT,UNARY,
+enum{DONE,ADD,SUBTRACT,MULTIPLY,DIVIDE,CARAT,MODULO,UNARY,
      NOT,EQ,NE,LT,LE,GT,GE,AND,OR,
      SQRT,EXP,LN,LOG,ABS,SIN,COS,TAN,ASIN,ACOS,ATAN,ATAN2,
      TMASS,DIST,
@@ -93,7 +93,7 @@ Variable::Variable(LAMMPS *lmp) : Pointers(lmp)
   precedence[EQ] = precedence[NE] = 3;
   precedence[LT] = precedence[LE] = precedence[GT] = precedence[GE] = 4;
   precedence[ADD] = precedence[SUBTRACT] = 5;
-  precedence[MULTIPLY] = precedence[DIVIDE] = 6;
+  precedence[MULTIPLY] = precedence[DIVIDE] = precedence[MODULO] = 6;
   precedence[CARAT] = 7;
   precedence[UNARY] = precedence[NOT] = 8;
 }
@@ -1339,6 +1339,7 @@ double Variable::evaluate(char *str, Tree **tree)
       else if (onechar == '-') op = SUBTRACT;
       else if (onechar == '*') op = MULTIPLY;
       else if (onechar == '/') op = DIVIDE;
+      else if (onechar == '%') op = MODULO;
       else if (onechar == '^') op = CARAT;
       else if (onechar == '=') {
         if (str[i+1] != '=')
@@ -1422,6 +1423,10 @@ double Variable::evaluate(char *str, Tree **tree)
             if (value2 == 0.0)
               error->all(FLERR,"Divide by 0 in variable formula");
             argstack[nargstack++] = value1 / value2;
+          } else if (opprevious == MODULO) {
+            if (value2 == 0.0)
+              error->all(FLERR,"Modulo 0 in variable formula");
+            argstack[nargstack++] = fmod(value1,value2);
           } else if (opprevious == CARAT) {
             if (value2 == 0.0)
               error->all(FLERR,"Power by 0 in variable formula");
@@ -1545,6 +1550,16 @@ double Variable::collapse_tree(Tree *tree)
     return tree->value;
   }
 
+  if (tree->type == MODULO) {
+    arg1 = collapse_tree(tree->left);
+    arg2 = collapse_tree(tree->right);
+    if (tree->left->type != VALUE || tree->right->type != VALUE) return 0.0;
+    tree->type = VALUE;
+    if (arg2 == 0.0) error->one(FLERR,"Modulo 0 in variable formula");
+    tree->value = fmod(arg1,arg2);
+    return tree->value;
+  }
+
   if (tree->type == CARAT) {
     arg1 = collapse_tree(tree->left);
     arg2 = collapse_tree(tree->right);
@@ -1975,6 +1990,11 @@ double Variable::eval_tree(Tree *tree, int i)
     if (denom == 0.0) error->one(FLERR,"Divide by 0 in variable formula");
     return eval_tree(tree->left,i) / denom;
   }
+  if (tree->type == MODULO) {
+    double denom = eval_tree(tree->right,i);
+    if (denom == 0.0) error->one(FLERR,"Modulo 0 in variable formula");
+    return fmod(eval_tree(tree->left,i),denom);
+  }
   if (tree->type == CARAT) {
     double exponent = eval_tree(tree->right,i);
     if (exponent == 0.0) error->one(FLERR,"Power by 0 in variable formula");
diff --git a/src/variable.h b/src/variable.h
index be71c40..c61071d 100644
--- a/src/variable.h
+++ b/src/variable.h
@@ -55,7 +55,7 @@ class Variable : protected Pointers {
   class RanMars *randomequal;   // random number generator for equal-style vars
   class RanMars *randomatom;    // random number generator for atom-style vars
 
-  int precedence[16];      // precedence level of math operators
+  int precedence[17];      // precedence level of math operators
                            // set length to include OR in enum
   int me;
 
